;; Generated package description from kind-icon.el  -*- no-byte-compile: t -*-
(define-package "kind-icon" "0.2.2.0.20240716.122822" "Completion kind icons" '((emacs "27.1") (svg-lib "0.2.8")) :commit "c15d6f127143ff3db22409c409ea1572c42166f8" :authors '(("J.D. Smith" . "jdtsmith@gmail.com")) :maintainer '("J.D. Smith" . "jdtsmith@gmail.com") :keywords '("completion" "convenience") :url "https://github.com/jdtsmith/kind-icon")
